@@ -23,10 +23,18 @@ TEST_CASE("io_write_float64_woven") {
   CHECK(write(js_woven_synthetic, jw_woven_float64));
 }
 
+TEST_CASE("io_write_float64_woven_perturbation") {
+  CHECK(write(js_woven_synthetic_perturbation, jw_woven_float64_perturbation));
+}
+
 TEST_CASE("io_write_float32_tornado") {
   CHECK(write(js_tornado_synthetic, jw_tornado_float32));
 }
 
+TEST_CASE("io_write_float32_moving_extremum_3d_synthetic") {
+  CHECK(write(js_moving_extremum_3d_synthetic, jw_moving_extremum_3d_float32));
+}
+
 #if FTK_HAVE_NETCDF
 TEST_CASE("io_write_nc_woven") {
   CHECK(write(js_woven_synthetic, jw_woven_nc_unlimited_time));
@@ -46,9 +54,17 @@ TEST_CASE("io_write_vti_woven") {
   CHECK(write(js_woven_synthetic, jw_woven_vti));
 }
 
+TEST_CASE("io_write_vti_volcano") {
+  CHECK(write(js_volcano_2d_synthetic, jw_volcano_vti));
+}
+
 TEST_CASE("io_write_vti_moving_extremum_2d_synthetic") {
   CHECK(write(js_moving_extremum_2d_synthetic, jw_moving_extremum_2d_vti));
 }
+
+TEST_CASE("io_write_vti_moving_ridge_3d_synthetic") {
+  CHECK(write(js_moving_ridge_3d_synthetic, jw_moving_ridge_3d_vti));
+}
 #endif
 
 int main(int argc, char **argv)
